@@ -9,6 +9,7 @@ logger = logging.getLogger(__name__)
 class BaseProcess(object):
     cache = None
     key_base = None
+    domain_key = None
 
     def __init__(self, cache, key_base):
         self.cache = cache
@@ -17,10 +18,20 @@ class BaseProcess(object):
     def run(self, hints=None):
         return
 
+    def domain(self, hints=None):
+        hints = hints or HintsManager(self.cache)
+        if self.domain_key:
+            try:
+                return hints.get(self.domain_key)['value']
+            except KeyError:
+                logger.warning(
+                    'IntervalRefreshProcess({}) - attempt to fetch domain key {} failed'
+                    .format(self.key_base, self.domain_key))
+        return []
+
 
 class IntervalRefreshProcess(BaseProcess):
     interval = datetime.timedelta(seconds=60)
-    domain_key = None
 
     def run(self, hints=None):
         hints = hints or HintsManager(self.cache)
@@ -31,13 +42,3 @@ class IntervalRefreshProcess(BaseProcess):
                 if datetime.datetime.utcnow() - cache_entry['modified'] >= self.interval:
                     self.cache.refresh(key, queued=True, hints=hints)
 
-    def domain(self, hints=None):
-        hints = hints or HintsManager(self.cache)
-        if self.domain_key:
-            try:
-                return hints.get(self.domain_key)['value']
-            except KeyError:
-                logger.warning(
-                    'IntervalRefreshProcess({}) - attempt to fetch domain key {} failed'
-                        .format(self.key_base, self.domain_key))
-        return None
